@@ -20,9 +20,7 @@ def setup_cmempy_super_user_access():
     try:
         os.environ["OAUTH_GRANT_TYPE"] = "client_credentials"
         if "CMEM_BASE_URI" not in os.environ:
-            os.environ["CMEM_BASE_URI"] = os.environ[
-                "DEPLOY_BASE_URL"
-            ]
+            os.environ["CMEM_BASE_URI"] = os.environ["DEPLOY_BASE_URL"]
         if "OAUTH_CLIENT_ID" not in os.environ:
             os.environ["OAUTH_CLIENT_ID"] = os.environ[
                 "DATAINTEGRATION_CMEM_SERVICE_CLIENT"
@@ -33,3 +31,23 @@ def setup_cmempy_super_user_access():
             ]
     except KeyError as error:
         raise ValueError("Super user configuration not available.") from error
+
+
+def split_task_id(task_id: str) -> tuple:
+    """Split a combined task ID.
+
+    Args:
+        task_id (str): The combined task ID.
+
+    Returns:
+        The project and task ID
+
+    Raises:
+        ValueError: in case the task ID is not splittable
+    """
+    try:
+        project_part = task_id.split(":")[0]
+        task_part = task_id.split(":")[1]
+    except IndexError as error:
+        raise ValueError(f"{task_id} is not a valid task ID.") from error
+    return project_part, task_part
